##  Submitting a Request in the SAP for Me Portal
### Context
Learn how to submit a support request in SAP for Me. For a video tutorial, visit: [Creating a Support Case in SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fvideos%2Fcreating-a-support-case-in-sap-for-me "https://learning.sap.com/videos/creating-a-support-case-in-sap-for-me").
### Procedure
  1. Go to the [SAP for Me Portal![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/") and log in with your credentials.
  2. Go to Services & Support > Get Support.
  3. Choose Report New Issue.
  4. Select a relevant customer.
  5. Fill in the basic information requested.
Be sure to select SAP LeanIX (LIX-EAM) as the affected system.
  6. Choose Continue.
SAP Support AI suggests a channel based on the basic information you provide.
  7. To create a case without using the recommended channel or one of the other alternatives, choose Create a Case.
  8. Provide detailed information about the question or problem, including:
    1. Steps to reproduce the problem.
    2. Timing of the issue occurrence.
    3. Screenshots or other relevant attachments.
    4. If related to workspace provisioning, provide the SAP Order ID.
You can find this in the Materials field of the Provisioning Status card for the relevant product.
    5. If applicable, assign additional contacts to the case.
    6. Choose Submit Case.
